@@ -6,18 +6,22 @@ import django
 
 from django.conf import settings
 
-from django.db.models import Manager
-
+# removed get_queryset <> get_query_set see, #29
+#from django.db.models import Manager
 ## Monkey patch:
-
-try:
-    Manager.get_query_set = Manager.get_queryset
-except AttributeError:
-    Manager.get_queryset = Manager.get_query_set
-
-
+#
+#try:
+#    Manager.get_query_set = Manager.get_queryset
+#except AttributeError:
+#    Manager.get_queryset = Manager.get_query_set
 
 
+if django.VERSION < (1, 8):
+    from django.template import add_to_builtins
+elif django.VERSION < (1, 9):
+    from django.template.base import add_to_builtins
+else:
+    pass  # Removed in 1.9. Use template settings instead
 
 
 try:
@@ -33,10 +37,10 @@ except ImportError:
 
 
 # get_indent
-if six.PY3:
+try:
     from threading import get_ident
-else:
-    from thread import get_ident  # noqa
+except ImportError:
+    from six.moves._thread import get_ident  # noqa
 
 try:
     from django.conf.urls import url, patterns, include, handler404, handler500
@@ -77,6 +81,13 @@ except ImportError:
 
 BytesIO = six.BytesIO
 
+try:
+    # Django 1.7 or over use the new application loading system
+    from django.apps import apps
+    get_model = apps.get_model
+except ImportError:
+    from django.db.models.loading import get_model
+    
 
 def get_model_name(model_cls):
     try:
@@ -227,6 +238,30 @@ def import_string(dotted_path):
         six.reraise(ImportError, ImportError(msg), sys.exc_info()[2])
 
 
+def commit(using=None):
+    """
+    Possibility of calling transaction.commit() in new Django versions (in atomic block).
+    """
+    try:
+        django.db.transaction.commit(using)
+    except django.db.transaction.TransactionManagementError:
+        pass
+
+
+def rollback(using=None, sid=None):
+    """
+    Possibility of calling transaction.rollback() in new Django versions (in atomic block).
+    Important: transaction savepoint (sid) is required for Django < 1.8
+    """
+    if sid:
+        django.db.transaction.savepoint_rollback(sid)
+    else:
+        try:
+             django.db.transaction.rollback(using)
+        except django.db.transaction.TransactionManagementError:
+             django.db.transaction.set_rollback(True, using)
+
+
 # HttpResponseBase only exists from 1.5 onwards
 try:
     from django.http.response import HttpResponseBase
@@ -329,10 +364,12 @@ try:
 except:
     from django.template.defaultfilters import slugify
 
-try:
-    from django.contrib.contenttypes.fields import GenericForeignKey
-except ImportError:  # django < 1.7
+if django.VERSION < (1, 7):
     from django.contrib.contenttypes.generic import GenericForeignKey
+elif django.VERSION < (1, 9):
+    from django.contrib.contenttypes.fields import GenericForeignKey
+else:
+    pass  # Loading models from __init__ is deprecated from 1.9. Import from compat.models instead
 
 # commit_on_success replaced by atomic in Django >=1.8
 atomic = commit_on_success = getattr(django.db.transaction, 'atomic', None) or getattr(django.db.transaction, 'commit_on_success')
@@ -340,10 +377,14 @@ atomic = commit_on_success = getattr(django.db.transaction, 'atomic', None) or g
 
 # the tests will try to import these
 __all__ = [
+    'add_to_builtins',
+    'get_model',
     'get_model_name',
     'get_user_model',
     'get_username_field',
     'import_string',
+    'commit',
+    'rollback',
     'user_model_label',
     'url',
     'patterns',
