@@ -22,12 +22,18 @@ def setup():
     }
 
     INSTALLED_APPS = [
+        'django.contrib.auth',
+        'django.contrib.contenttypes',
         'compat',
+        'compat.tests.test_app',
     ]
-    if django.VERSION >= (1,6):
-        TEST_RUNNER = 'django.test.runner.DiscoverRunner'
-    else:
-        TEST_RUNNER = 'django.test.simple.DjangoTestSuiteRunner'
+    if django.VERSION < (1, 7):
+        INSTALLED_APPS.append('compat.tests')
+
+
+    MIDDLEWARE_CLASSES = []
+    if django.VERSION < (1, 7):
+        MIDDLEWARE_CLASSES.append('django.middleware.transaction.TransactionMiddleware')
 
     from django.conf import settings
 
@@ -35,25 +41,18 @@ def setup():
         settings.configure(
             INSTALLED_APPS=INSTALLED_APPS,
             DATABASES=DATABASES,
-            TEST_RUNNER=TEST_RUNNER,
-            ROOT_URLCONF='compat.tests.urls'
-        )
-
-
+            ROOT_URLCONF='compat.tests.urls',
+            MIDDLEWARE_CLASSES = MIDDLEWARE_CLASSES, )
 
 
 def runtests(*test_args):
 
-    if django.VERSION >= (1,7):
+    if django.VERSION >= (1, 7):
         django.setup()
 
-
-    from django.test.utils import get_runner
-    TestRunner = get_runner(settings)
-    test_runner = TestRunner(verbosity=1, interactive=False, failfast=False)
-
-    failures = test_runner.run_tests(test_args)
-
+    from django_nose import NoseTestSuiteRunner
+    failures = NoseTestSuiteRunner(verbosity=2,
+                                      interactive=True).run_tests(test_args)
     sys.exit(failures)
 
 
